<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ActionsShortcutsModel</name>
    <message>
        <location filename="../shortcuts_management/actions_shortcuts_model.cpp" line="73"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <location filename="bookmarks_dialog.cpp" line="75"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="107"/>
        <location filename="bookmarks_dialog.cpp" line="124"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="85"/>
        <source>Click on any image to go to the bookmark</source>
        <translation>Click su qualsiasi immagine per andare al bookmark</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="25"/>
        <source>Lastest Page</source>
        <translation>Ultima Pagina</translation>
    </message>
</context>
<context>
    <name>EditShortcutsDialog</name>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>Shortcut in use</source>
        <translation>Scorciatoia in uso</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="23"/>
        <source>Restore defaults</source>
        <translation>Resetta al default</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="71"/>
        <source>Shortcuts settings</source>
        <translation>impostazione scorciatoie</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>The shortcut &quot;%1&quot; is already assigned to other function</source>
        <translation>La scorciatoia &quot;%1&quot; è già assegnata ad un&apos;altra funzione</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="24"/>
        <source>To change a shortcut, double click in the key combination and type the new keys.</source>
        <translation>Per cambiare una scorciatoia doppio click sulla combinazione tasti e digita la nuova combinazione.</translation>
    </message>
</context>
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation>Formato non supportato</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation>7z non trovato</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation>Errore sconosciuto aprendo il file</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation>Errore CRC alla pagina (%1): alcune pagine non saranno visualizzate correttamente</translation>
    </message>
</context>
<context>
    <name>GoToDialog</name>
    <message>
        <location filename="goto_dialog.cpp" line="23"/>
        <source>Go To</source>
        <translation>Vai a</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="53"/>
        <source>Go to...</source>
        <translation>Vai a...</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="39"/>
        <location filename="goto_dialog.cpp" line="71"/>
        <source>Total pages : </source>
        <translation>Pagine totali: </translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="25"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="15"/>
        <source>Page : </source>
        <translation>Pagina: </translation>
    </message>
</context>
<context>
    <name>GoToFlowToolBar</name>
    <message>
        <location filename="goto_flow_toolbar.cpp" line="38"/>
        <source>Page : </source>
        <translation>Pagina: </translation>
    </message>
</context>
<context>
    <name>HelpAboutDialog</name>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="31"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="34"/>
        <source>System info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="28"/>
        <source>About</source>
        <translation>About</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowViewer</name>
    <message>
        <source>Go</source>
        <translation type="vanished">Vai</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="vanished">Edit</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">File</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Aiuto</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Salva</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Mostra</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="vanished">&amp;File</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="vanished">&amp;Prossimo</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">&amp;Apri</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="vanished">Cancella</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Chiudi</translation>
    </message>
    <message>
        <source>Open Comic</source>
        <translation type="vanished">Apri Fumetto</translation>
    </message>
    <message>
        <source>Go To</source>
        <translation type="vanished">Vai a</translation>
    </message>
    <message>
        <source>Zoom+</source>
        <translation type="vanished">Zoom+</translation>
    </message>
    <message>
        <source>Zoom-</source>
        <translation type="vanished">Zoom-</translation>
    </message>
    <message>
        <source>Open image folder</source>
        <translation type="vanished">Apri la crettal immagini</translation>
    </message>
    <message>
        <source>Size down magnifying glass</source>
        <translation type="vanished">Riduci lente ingrandimento</translation>
    </message>
    <message>
        <source>Zoom out magnifying glass</source>
        <translation type="vanished">Riduci in lente di ingrandimento</translation>
    </message>
    <message>
        <source>Open latest comic</source>
        <translation type="vanished">Apri l&apos;ultimo fumetto</translation>
    </message>
    <message>
        <source>Autoscroll up</source>
        <translation type="vanished">Autoscorri Sù</translation>
    </message>
    <message>
        <source>Set bookmark</source>
        <translation type="vanished">Imposta Segnalibro</translation>
    </message>
    <message>
        <source>page_%1.jpg</source>
        <translation type="vanished">Pagina_%1.jpg</translation>
    </message>
    <message>
        <source>Autoscroll forward, vertical first</source>
        <translation type="vanished">Autoscorri avanti, priorità Verticale</translation>
    </message>
    <message>
        <source>Switch to double page mode</source>
        <translation type="vanished">Passa alla modalità doppia pagina</translation>
    </message>
    <message>
        <source>Save current page</source>
        <translation type="vanished">Salva la pagina corrente</translation>
    </message>
    <message>
        <source>Size up magnifying glass</source>
        <translation type="vanished">Ingrandisci lente ingrandimento</translation>
    </message>
    <message>
        <source>Double page mode</source>
        <translation type="vanished">Modalita doppia pagina</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation type="vanished">Muovi Sù</translation>
    </message>
    <message>
        <source>Switch Magnifying glass</source>
        <translation type="vanished">Passa a lente ingrandimento</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="vanished">Apri una cartella</translation>
    </message>
    <message>
        <source>Comics</source>
        <translation type="vanished">Fumetto</translation>
    </message>
    <message>
        <source>Fit Height</source>
        <translation type="vanished">Adatta altezza</translation>
    </message>
    <message>
        <source>Autoscroll backward, vertical first</source>
        <translation type="vanished">Autoscorri indietro, priorità Verticale</translation>
    </message>
    <message>
        <source>Comic files</source>
        <translation type="vanished">File Fumetto</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="vanished">Non ora</translation>
    </message>
    <message>
        <source>Go to the first page</source>
        <translation type="vanished">Vai alla pagina iniziale</translation>
    </message>
    <message>
        <source>Go to previous page</source>
        <translation type="vanished">Vai alla pagina precedente</translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="vanished">Finestra</translation>
    </message>
    <message>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="vanished">Apri l&apos;ultimo fumetto aperto nella sessione precedente</translation>
    </message>
    <message>
        <source>Open a comic</source>
        <translation type="vanished">Apri un Fumetto</translation>
    </message>
    <message>
        <source>Image files (*.jpg)</source>
        <translation type="vanished">File immagine (*.jpg)</translation>
    </message>
    <message>
        <source>Next Comic</source>
        <translation type="vanished">Prossimo fumetto</translation>
    </message>
    <message>
        <source>Fit Width</source>
        <translation type="vanished">Adatta Larghezza</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="vanished">Opzioni</translation>
    </message>
    <message>
        <source>Show Info</source>
        <translation type="vanished">Mostra info</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Apri cartella</translation>
    </message>
    <message>
        <source>Go to page ...</source>
        <translation type="vanished">Vai a Pagina ...</translation>
    </message>
    <message>
        <source>Magnifiying glass</source>
        <translation type="vanished">Lente ingrandimento</translation>
    </message>
    <message>
        <source>Fit image to width</source>
        <translation type="vanished">Adatta immagine in larghezza</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode</source>
        <translation type="vanished">Attiva/Disattiva schermo intero</translation>
    </message>
    <message>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="vanished">Passa tra adatta in larghezza ad altezza</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation type="vanished">Muovi Destra</translation>
    </message>
    <message>
        <source>Zoom in magnifying glass</source>
        <translation type="vanished">Ingrandisci in lente di ingrandimento</translation>
    </message>
    <message>
        <source>Open recent</source>
        <translation type="vanished">Apri i recenti</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Leggi</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="vanished">&amp;Precedente</translation>
    </message>
    <message>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="vanished">Autoscorri avanti, priorità Orizzontale</translation>
    </message>
    <message>
        <source>Go to next page</source>
        <translation type="vanished">Vai alla prossima Pagina</translation>
    </message>
    <message>
        <source>Show keyboard shortcuts</source>
        <translation type="vanished">Mostra scorciatoie da tastiera</translation>
    </message>
    <message>
        <source>Double page manga mode</source>
        <translation type="vanished">Modalità doppia pagina Manga</translation>
    </message>
    <message>
        <source>There is a new version available</source>
        <translation type="vanished">Nuova versione disponibile</translation>
    </message>
    <message>
        <source>Autoscroll down</source>
        <translation type="vanished">Autoscorri Giù</translation>
    </message>
    <message>
        <source>Open next comic</source>
        <translation type="vanished">Apri il prossimo fumetto</translation>
    </message>
    <message>
        <source>Remind me in 14 days</source>
        <translation type="vanished">Ricordamelo in 14 giorni</translation>
    </message>
    <message>
        <source>Fit to page</source>
        <translation type="vanished">Adatta alla pagina</translation>
    </message>
    <message>
        <source>Show bookmarks</source>
        <translation type="vanished">Mostra segnalibro</translation>
    </message>
    <message>
        <source>Open previous comic</source>
        <translation type="vanished">Apri il fumetto precendente</translation>
    </message>
    <message>
        <source>Rotate image to the left</source>
        <translation type="vanished">Ruota immagine a sinistra</translation>
    </message>
    <message>
        <source>Fit image to height</source>
        <translation type="vanished">Adatta immagine all&apos;altezza</translation>
    </message>
    <message>
        <source>Reset zoom</source>
        <translation type="vanished">Resetta Zoom</translation>
    </message>
    <message>
        <source>Show the bookmarks of the current comic</source>
        <translation type="vanished">Mostra il segnalibro del fumetto corrente</translation>
    </message>
    <message>
        <source>Show Dictionary</source>
        <translation type="vanished">Mostra dizionario</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation type="vanished">Muovi Giù</translation>
    </message>
    <message>
        <source>Move left</source>
        <translation type="vanished">Muovi Sinistra</translation>
    </message>
    <message>
        <source>Reverse reading order in double page mode</source>
        <translation type="vanished">Ordine lettura inverso in modo doppia pagina</translation>
    </message>
    <message>
        <source>YACReader options</source>
        <translation type="vanished">Opzioni YACReader</translation>
    </message>
    <message>
        <source>Clear open recent list</source>
        <translation type="vanished">Svuota la lista degli aperti</translation>
    </message>
    <message>
        <source>Help, About YACReader</source>
        <translation type="vanished">Aiuto, crediti YACReader</translation>
    </message>
    <message>
        <source>Show go to flow</source>
        <translation type="vanished">Mostra vai all&apos;elenco</translation>
    </message>
    <message>
        <source>Previous Comic</source>
        <translation type="vanished">Fumetto precendente</translation>
    </message>
    <message>
        <source>Show full size</source>
        <translation type="vanished">Mostra dimesioni reali</translation>
    </message>
    <message>
        <source>Hide/show toolbar</source>
        <translation type="vanished">Mostra/Nascondi Barra strumenti</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation type="vanished">Lente ingrandimento</translation>
    </message>
    <message>
        <source>Edit shortcuts</source>
        <translation type="vanished">Edita scorciatoie</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Generale</translation>
    </message>
    <message>
        <source>Set a bookmark on the current page</source>
        <translation type="vanished">Imposta segnalibro a pagina corrente</translation>
    </message>
    <message>
        <source>Page adjustement</source>
        <translation type="vanished">Correzioni di pagna</translation>
    </message>
    <message>
        <source>Show zoom slider</source>
        <translation type="vanished">Mostra cursore di zoom</translation>
    </message>
    <message>
        <source>Go to the last page</source>
        <translation type="vanished">Vai all&apos;ultima pagina</translation>
    </message>
    <message>
        <source>Do you want to download the new version?</source>
        <translation type="vanished">Vuoi scaricare la nuova versione?</translation>
    </message>
    <message>
        <source>Rotate image to the right</source>
        <translation type="vanished">Ruota immagine a destra</translation>
    </message>
    <message>
        <source>Always on top</source>
        <translation type="vanished">Sempre in primo piano</translation>
    </message>
    <message>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="vanished">Autoscorri indietro, priorità Orizzontale</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="options_dialog.cpp" line="166"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="170"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="34"/>
        <source>My comics path</source>
        <translation>Percorso dei miei fumetti</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="214"/>
        <source>Image adjustment</source>
        <translation>Correzioni immagine</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="49"/>
        <source>&quot;Go to flow&quot; size</source>
        <translation>Dimensione &quot;Vai all&apos;elenco&quot;</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="70"/>
        <source>Choose</source>
        <translation>Scegli</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="175"/>
        <source>Image options</source>
        <translation>Opzione immagine</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="165"/>
        <source>Contrast</source>
        <translation>Contrasto</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="229"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="236"/>
        <source>Comics directory</source>
        <translation>Cartella Fumetti</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="120"/>
        <source>Quick Navigation Mode</source>
        <translation>Modo navigazione rapida</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="41"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="43"/>
        <source>Show time in current page information label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="67"/>
        <source>Background color</source>
        <translation>Colore di sfondo</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="77"/>
        <source>Scroll behaviour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="80"/>
        <source>Disable scroll animations and smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="81"/>
        <source>Do not turn page using scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="82"/>
        <source>Use single scroll step to turn page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="90"/>
        <source>Mouse mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="93"/>
        <source>Only Back/Forward buttons can turn pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="94"/>
        <source>Use the Left/Right buttons to turn pages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="95"/>
        <source>Click left or right half of the screen to turn pages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="121"/>
        <source>Disable mouse over activation</source>
        <translation>Disabilita il mouse all&apos;attivazione</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="213"/>
        <source>Page Flow</source>
        <translation>Flusso pagine</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="212"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="164"/>
        <source>Brightness</source>
        <translation>Luminosità</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="220"/>
        <source>Restart is needed</source>
        <translation>Riavvio Necessario</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="179"/>
        <source>Fit options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="181"/>
        <source>Enlarge images to fit width/height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="192"/>
        <source>Double Page options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="194"/>
        <source>Show covers as single page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>7z lib not found</source>
        <translation>Libreria 7z non trovata</translation>
    </message>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>unable to load 7z lib from ./utils</source>
        <translation>Impossibile caricare 7z da ./utils</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/yacreader_global_gui.cpp" line="112"/>
        <source>Select custom cover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/yacreader_global_gui.cpp" line="112"/>
        <source>Images (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsDialog</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Chiudi</translation>
    </message>
    <message>
        <source>YACReader keyboard shortcuts</source>
        <translation type="vanished">Scorciatoie  da tastiera di YACReader</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts</source>
        <translation type="vanished">Scorciatoia da tastiera</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="viewer.cpp" line="1001"/>
        <source>Page not available!</source>
        <translation>Pagina non disponibile!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="51"/>
        <location filename="viewer.cpp" line="979"/>
        <source>Press &apos;O&apos; to open comic.</source>
        <translation>Premi &quot;O&quot; per aprire il fumettto.</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="252"/>
        <source>Error opening comic</source>
        <translation>Errore nell&apos;apertura</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1164"/>
        <source>Cover!</source>
        <translation>Copertina!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="258"/>
        <source>CRC Error</source>
        <translation>Errore CRC</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>Comic not found</source>
        <translation>Fumetto non trovato</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>Not found</source>
        <translation>Non trovato</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1178"/>
        <source>Last page!</source>
        <translation>Ultima pagina!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="991"/>
        <source>Loading...please wait!</source>
        <translation>In caricamento...Attendi!</translation>
    </message>
</context>
<context>
    <name>YACReader::MainWindowViewer</name>
    <message>
        <location filename="main_window_viewer.cpp" line="187"/>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Apri</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="189"/>
        <source>Open a comic</source>
        <translation type="unfinished">Apri un Fumetto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="195"/>
        <source>New instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="214"/>
        <source>Open Folder</source>
        <translation type="unfinished">Apri una cartella</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="216"/>
        <source>Open image folder</source>
        <translation type="unfinished">Apri la crettal immagini</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="221"/>
        <source>Open latest comic</source>
        <translation type="unfinished">Apri l&apos;ultimo fumetto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="222"/>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="unfinished">Apri l&apos;ultimo fumetto aperto nella sessione precedente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="234"/>
        <source>Clear</source>
        <translation type="unfinished">Cancella</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="235"/>
        <source>Clear open recent list</source>
        <translation type="unfinished">Svuota la lista degli aperti</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="238"/>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="240"/>
        <location filename="main_window_viewer.cpp" line="957"/>
        <source>Save current page</source>
        <translation type="unfinished">Salva la pagina corrente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="245"/>
        <source>Previous Comic</source>
        <translation type="unfinished">Fumetto precendente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="247"/>
        <location filename="main_window_viewer.cpp" line="1680"/>
        <location filename="main_window_viewer.cpp" line="1684"/>
        <source>Open previous comic</source>
        <translation type="unfinished">Apri il fumetto precendente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="252"/>
        <source>Next Comic</source>
        <translation type="unfinished">Prossimo fumetto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="254"/>
        <location filename="main_window_viewer.cpp" line="1679"/>
        <location filename="main_window_viewer.cpp" line="1685"/>
        <source>Open next comic</source>
        <translation type="unfinished">Apri il prossimo fumetto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="259"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Precedente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="262"/>
        <location filename="main_window_viewer.cpp" line="1682"/>
        <location filename="main_window_viewer.cpp" line="1686"/>
        <source>Go to previous page</source>
        <translation type="unfinished">Vai alla pagina precedente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="267"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Prossimo</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="270"/>
        <location filename="main_window_viewer.cpp" line="1681"/>
        <location filename="main_window_viewer.cpp" line="1687"/>
        <source>Go to next page</source>
        <translation type="unfinished">Vai alla prossima Pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="275"/>
        <source>Fit Height</source>
        <translation type="unfinished">Adatta altezza</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="278"/>
        <source>Fit image to height</source>
        <translation type="unfinished">Adatta immagine all&apos;altezza</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="285"/>
        <source>Fit Width</source>
        <translation type="unfinished">Adatta Larghezza</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="288"/>
        <source>Fit image to width</source>
        <translation type="unfinished">Adatta immagine in larghezza</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="295"/>
        <source>Show full size</source>
        <translation type="unfinished">Mostra dimesioni reali</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="303"/>
        <source>Fit to page</source>
        <translation type="unfinished">Adatta alla pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="334"/>
        <source>Reset zoom</source>
        <translation type="unfinished">Resetta Zoom</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="339"/>
        <source>Show zoom slider</source>
        <translation type="unfinished">Mostra cursore di zoom</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="342"/>
        <source>Zoom+</source>
        <translation type="unfinished">Zoom+</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="347"/>
        <source>Zoom-</source>
        <translation type="unfinished">Zoom-</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="352"/>
        <source>Rotate image to the left</source>
        <translation type="unfinished">Ruota immagine a sinistra</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="358"/>
        <source>Rotate image to the right</source>
        <translation type="unfinished">Ruota immagine a destra</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="364"/>
        <source>Double page mode</source>
        <translation type="unfinished">Modalita doppia pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="365"/>
        <source>Switch to double page mode</source>
        <translation type="unfinished">Passa alla modalità doppia pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="374"/>
        <source>Double page manga mode</source>
        <translation type="unfinished">Modalità doppia pagina Manga</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="375"/>
        <source>Reverse reading order in double page mode</source>
        <translation type="unfinished">Ordine lettura inverso in modo doppia pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="384"/>
        <source>Go To</source>
        <translation type="unfinished">Vai a</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="386"/>
        <source>Go to page ...</source>
        <translation type="unfinished">Vai a Pagina ...</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="391"/>
        <source>Options</source>
        <translation type="unfinished">Opzioni</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="392"/>
        <source>YACReader options</source>
        <translation type="unfinished">Opzioni YACReader</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="399"/>
        <location filename="main_window_viewer.cpp" line="696"/>
        <source>Help</source>
        <translation type="unfinished">Aiuto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="400"/>
        <source>Help, About YACReader</source>
        <translation type="unfinished">Aiuto, crediti YACReader</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="406"/>
        <source>Magnifying glass</source>
        <translation type="unfinished">Lente ingrandimento</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="407"/>
        <source>Switch Magnifying glass</source>
        <translation type="unfinished">Passa a lente ingrandimento</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="414"/>
        <source>Set bookmark</source>
        <translation type="unfinished">Imposta Segnalibro</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="415"/>
        <source>Set a bookmark on the current page</source>
        <translation type="unfinished">Imposta segnalibro a pagina corrente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="424"/>
        <source>Show bookmarks</source>
        <translation type="unfinished">Mostra segnalibro</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="425"/>
        <source>Show the bookmarks of the current comic</source>
        <translation type="unfinished">Mostra il segnalibro del fumetto corrente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="431"/>
        <source>Show keyboard shortcuts</source>
        <translation type="unfinished">Mostra scorciatoie da tastiera</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="437"/>
        <source>Show Info</source>
        <translation type="unfinished">Mostra info</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="443"/>
        <source>Close</source>
        <translation type="unfinished">Chiudi</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="449"/>
        <source>Show Dictionary</source>
        <translation type="unfinished">Mostra dizionario</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="456"/>
        <source>Show go to flow</source>
        <translation type="unfinished">Mostra vai all&apos;elenco</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="462"/>
        <source>Edit shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="485"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;File</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="500"/>
        <location filename="main_window_viewer.cpp" line="651"/>
        <source>Open recent</source>
        <translation type="unfinished">Apri i recenti</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="640"/>
        <source>File</source>
        <translation type="unfinished">File</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="661"/>
        <source>Edit</source>
        <translation type="unfinished">Edit</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="665"/>
        <source>View</source>
        <translation type="unfinished">Mostra</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="681"/>
        <source>Go</source>
        <translation type="unfinished">Vai</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="689"/>
        <source>Window</source>
        <translation type="unfinished">Finestra</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="806"/>
        <location filename="main_window_viewer.cpp" line="808"/>
        <location filename="main_window_viewer.cpp" line="810"/>
        <source>Open Comic</source>
        <translation type="unfinished">Apri Fumetto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="806"/>
        <location filename="main_window_viewer.cpp" line="808"/>
        <location filename="main_window_viewer.cpp" line="810"/>
        <source>Comic files</source>
        <translation type="unfinished">File Fumetto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="901"/>
        <source>Open folder</source>
        <translation type="unfinished">Apri cartella</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="957"/>
        <source>page_%1.jpg</source>
        <translation type="unfinished">Pagina_%1.jpg</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="957"/>
        <source>Image files (*.jpg)</source>
        <translation type="unfinished">File immagine (*.jpg)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1164"/>
        <source>Comics</source>
        <translation type="unfinished">Fumetto</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1174"/>
        <source>Toggle fullscreen mode</source>
        <translation type="unfinished">Attiva/Disattiva schermo intero</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1177"/>
        <source>Hide/show toolbar</source>
        <translation type="unfinished">Mostra/Nascondi Barra strumenti</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1180"/>
        <source>General</source>
        <translation type="unfinished">Generale</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1199"/>
        <source>Size up magnifying glass</source>
        <translation type="unfinished">Ingrandisci lente ingrandimento</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1202"/>
        <source>Size down magnifying glass</source>
        <translation type="unfinished">Riduci lente ingrandimento</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1205"/>
        <source>Zoom in magnifying glass</source>
        <translation type="unfinished">Ingrandisci in lente di ingrandimento</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1208"/>
        <source>Zoom out magnifying glass</source>
        <translation type="unfinished">Riduci in lente di ingrandimento</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1211"/>
        <source>Reset magnifying glass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1218"/>
        <source>Magnifiying glass</source>
        <translation type="unfinished">Lente ingrandimento</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1225"/>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="unfinished">Passa tra adatta in larghezza ad altezza</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1229"/>
        <source>Page adjustement</source>
        <translation type="unfinished">Correzioni di pagna</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1246"/>
        <source>Autoscroll down</source>
        <translation type="unfinished">Autoscorri Giù</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1249"/>
        <source>Autoscroll up</source>
        <translation type="unfinished">Autoscorri Sù</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1252"/>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="unfinished">Autoscorri avanti, priorità Orizzontale</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1256"/>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="unfinished">Autoscorri indietro, priorità Orizzontale</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1260"/>
        <source>Autoscroll forward, vertical first</source>
        <translation type="unfinished">Autoscorri avanti, priorità Verticale</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1264"/>
        <source>Autoscroll backward, vertical first</source>
        <translation type="unfinished">Autoscorri indietro, priorità Verticale</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1268"/>
        <source>Move down</source>
        <translation type="unfinished">Muovi Giù</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1271"/>
        <source>Move up</source>
        <translation type="unfinished">Muovi Sù</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1274"/>
        <source>Move left</source>
        <translation type="unfinished">Muovi Sinistra</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1277"/>
        <source>Move right</source>
        <translation type="unfinished">Muovi Destra</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1280"/>
        <source>Go to the first page</source>
        <translation type="unfinished">Vai alla pagina iniziale</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1283"/>
        <source>Go to the last page</source>
        <translation type="unfinished">Vai all&apos;ultima pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1286"/>
        <source>Offset double page to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1288"/>
        <source>Offset double page to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1306"/>
        <source>Reading</source>
        <translation type="unfinished">Leggi</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1355"/>
        <source>There is a new version available</source>
        <translation type="unfinished">Nuova versione disponibile</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1356"/>
        <source>Do you want to download the new version?</source>
        <translation type="unfinished">Vuoi scaricare la nuova versione?</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1359"/>
        <source>Remind me in 14 days</source>
        <translation type="unfinished">Ricordamelo in 14 giorni</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1360"/>
        <source>Not now</source>
        <translation type="unfinished">Non ora</translation>
    </message>
</context>
<context>
    <name>YACReader::WhatsNewDialog</name>
    <message>
        <location filename="../custom_widgets/whats_new_dialog.cpp" line="116"/>
        <source>Close</source>
        <translation type="unfinished">Chiudi</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="11"/>
        <source>Restore to default</source>
        <translation>Resetta al default</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="28"/>
        <source>Click to overwrite</source>
        <translation>Click per sovrascrivere</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldPlainTextEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="10"/>
        <source>Restore to default</source>
        <translation>Resetta al default</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="19"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="44"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="50"/>
        <source>Click to overwrite</source>
        <translation>Click per sovrascrivere</translation>
    </message>
</context>
<context>
    <name>YACReaderFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="15"/>
        <source>CoverFlow look</source>
        <translation>Aspetto flusso Copertine</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="13"/>
        <source>How to show covers:</source>
        <translation>Come mostrare le copertine:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="16"/>
        <source>Stripe look</source>
        <translation>Aspetto a strisce</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="17"/>
        <source>Overlapped Stripe look</source>
        <translation>Aspetto a strisce sovrapposto</translation>
    </message>
</context>
<context>
    <name>YACReaderGLFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="112"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="142"/>
        <source>Light</source>
        <translation>Luce</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="76"/>
        <source>Show advanced settings</source>
        <translation>Mostra opzioni avanzate</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="32"/>
        <source>Roulette look</source>
        <translation>Aspetto Roulette</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="130"/>
        <source>Cover Angle</source>
        <translation>Angolo copertine</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="23"/>
        <source>Stripe look</source>
        <translation>Aspetto a strisce</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="94"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="124"/>
        <source>Z offset</source>
        <translation>Compensazione Z</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="118"/>
        <source>Y offset</source>
        <translation>Compensazione Y</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="106"/>
        <source>Central gap</source>
        <translation>Distanza centrale</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="18"/>
        <source>Presets:</source>
        <translation>Preselezioni:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="26"/>
        <source>Overlapped Stripe look</source>
        <translation>Aspetto a strisce sovrapposto</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="29"/>
        <source>Modern look</source>
        <translation>Aspetto moderno</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="88"/>
        <source>View angle</source>
        <translation>Angolo di vista</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="148"/>
        <source>Max angle</source>
        <translation>Angolo massimo</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="85"/>
        <source>Custom:</source>
        <translation>Personalizzazione:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="20"/>
        <source>Classic look</source>
        <translation>Aspetto Classico</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="100"/>
        <source>Cover gap</source>
        <translation>Distanza Copertine</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="182"/>
        <source>High Performance</source>
        <translation>Prestazioni Alte</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="201"/>
        <source>Performance:</source>
        <translation>Prestazioni:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="193"/>
        <source>Use VSync (improve the image quality in fullscreen mode, worse performance)</source>
        <translation>Usa VSync (migliora la qualtà a tutto schermo, peggiora le prestazioni)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="136"/>
        <source>Visibility</source>
        <translation>Visibilità</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="180"/>
        <source>Low Performance</source>
        <translation>Prestazioni Basse</translation>
    </message>
</context>
<context>
    <name>YACReaderOptionsDialog</name>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="46"/>
        <source>Use hardware acceleration (restart needed)</source>
        <translation>Usa accelerazione Hardware (necessita restart)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="37"/>
        <source>Shortcuts</source>
        <translation>Scorciatoia</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="34"/>
        <source>Edit shortcuts</source>
        <translation>Edita Scorciatoia</translation>
    </message>
</context>
<context>
    <name>YACReaderSlider</name>
    <message>
        <location filename="width_slider.cpp" line="49"/>
        <source>Reset</source>
        <translation>Resetta</translation>
    </message>
</context>
<context>
    <name>YACReaderTranslator</name>
    <message>
        <location filename="translator.cpp" line="139"/>
        <source>clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="216"/>
        <source>Service not available</source>
        <translation>Servizio non disponibile</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="116"/>
        <location filename="translator.cpp" line="207"/>
        <source>Translation</source>
        <translation>Traduzione</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="62"/>
        <source>YACReader translator</source>
        <translation>Traduttore YACReader</translation>
    </message>
</context>
</TS>
